==> sca-patterns-sle12-1.5.5.tar.gz: sca-patterns-sle12-1.5.5/patterns/SLE/sle12sp1/glibc_SUSE-SU-2016_0471-1_12.1.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for glibc SUSE-SU-2016:0471-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP1
# Source:      Security Announcement Parser v1.3.0
# Modified:    2016 Feb 17
#
##############################################################################
# Copyright (C) 2016 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jrecord@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "glibc"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_TID"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_TID=https://www.suse.com/support/kb/doc.php?id=7017265|META_LINK_Security=http://lists.opensuse.org/opensuse-security-announce/2016-02/msg00037.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'glibc'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2016:0471-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 12):
	if ( SERVER['DistroPatchLevel'] == 1 ):
		PACKAGES = {
			'glibc': '2.19-35.1',
			'glibc-32bit': '2.19-35.1',
			'glibc-debuginfo': '2.19-35.1',
			'glibc-debuginfo-32bit': '2.19-35.1',
			'glibc-debugsource': '2.19-35.1',
			'glibc-devel': '2.19-35.1',
			'glibc-devel-32bit': '2.19-35.1',
			'glibc-devel-debuginfo': '2.19-35.1',
			'glibc-devel-debuginfo-32bit': '2.19-35.1',
			'glibc-devel-static': '2.19-35.1',
			'glibc-html': '2.19-35.1',
			'glibc-i18ndata': '2.19-35.1',
			'glibc-info': '2.19-35.1',
			'glibc-locale': '2.19-35.1',
			'glibc-locale-32bit': '2.19-35.1',
			'glibc-locale-debuginfo': '2.19-35.1',
			'glibc-locale-debuginfo-32bit': '2.19-35.1',
			'glibc-profile': '2.19-35.1',
			'glibc-profile-32bit': '2.19-35.1',
			'nscd': '2.19-35.1',
			'nscd-debuginfo': '2.19-35.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle12-1.5.7.tar.gz: sca-patterns-sle12-1.5.7/patterns/SLE/sle12sp1/glibc_SUSE-SU-2018_0071-1_12.1.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for glibc SUSE-SU-2018:0071-1
# Description: Security fixes for SUSE Linux Enterprise 12 SP1
# Source:      Security Announcement Parser v1.3.6
# Modified:    2018 Jan 19
#
##############################################################################
# Copyright (C) 2018 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record (jason.record@suse.com)
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "glibc"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.opensuse.org/opensuse-security-announce/2018-01/msg00035.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'glibc'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2018:0071-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 12):
	if ( SERVER['DistroPatchLevel'] == 1 ):
		PACKAGES = {
			'glibc': '2.19-40.9.5',
			'glibc-32bit': '2.19-40.9.5',
			'glibc-debuginfo': '2.19-40.9.5',
			'glibc-debuginfo-32bit': '2.19-40.9.5',
			'glibc-debugsource': '2.19-40.9.5',
			'glibc-devel': '2.19-40.9.5',
			'glibc-devel-32bit': '2.19-40.9.5',
			'glibc-devel-debuginfo': '2.19-40.9.5',
			'glibc-devel-debuginfo-32bit': '2.19-40.9.5',
			'glibc-html': '2.19-40.9.5',
			'glibc-i18ndata': '2.19-40.9.5',
			'glibc-info': '2.19-40.9.5',
			'glibc-locale': '2.19-40.9.5',
			'glibc-locale-32bit': '2.19-40.9.5',
			'glibc-locale-debuginfo': '2.19-40.9.5',
			'glibc-locale-debuginfo-32bit': '2.19-40.9.5',
			'glibc-profile': '2.19-40.9.5',
			'glibc-profile-32bit': '2.19-40.9.5',
			'nscd': '2.19-40.9.5',
			'nscd-debuginfo': '2.19-40.9.5',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
